@@ -24,6 +24,7 @@ from .service import (
     EmptyResponse,
     Fleet,
     Fleets,
+    GetFleetListRequest,
     GetFleetLiveMapRequest,
     GetFleetLiveMapResponse,
     GetFleetRequest,
@@ -51,6 +52,7 @@ __all__ = (
     'EmptyResponse',
     'Fleet',
     'Fleets',
+    'GetFleetListRequest',
     'GetFleetLiveMapRequest',
     'GetFleetLiveMapResponse',
     'GetFleetRequest',
