@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,6 +15,8 @@
 #
 
 from .services.trade_flow_service import TradeFlowServiceClient
+from .services.trade_flow_service import TradeFlowServiceAsyncClient
+
 from .types.service import AggregationGroup
 from .types.service import AggregationRow
 from .types.service import EmptyParams
@@ -24,8 +25,8 @@ from .types.service import GeoPoint
 from .types.service import GetLocationVolumeResponse
 from .types.service import GetTradeFlowAggregationResponse
 from .types.service import GetTradeFlowHistogramResponse
-from .types.service import GetTradeFlowTimeseriesResponse
 from .types.service import GetTradeFlowsResponse
+from .types.service import GetTradeFlowTimeseriesResponse
 from .types.service import GetTradeLaneMetricsResponse
 from .types.service import HistogramGroup
 from .types.service import LocationVolume
@@ -35,25 +36,25 @@ from .types.service import TradeFlow
 from .types.service import TradeFlowDataRequest
 from .types.service import TradeLaneMetric
 
-
 __all__ = (
-    'AggregationGroup',
-    'AggregationRow',
-    'EmptyParams',
-    'EmptyResponse',
-    'GeoPoint',
-    'GetLocationVolumeResponse',
-    'GetTradeFlowAggregationResponse',
-    'GetTradeFlowHistogramResponse',
-    'GetTradeFlowTimeseriesResponse',
-    'GetTradeFlowsResponse',
-    'GetTradeLaneMetricsResponse',
-    'HistogramGroup',
-    'LocationVolume',
-    'TimeseriesGroup',
-    'TimeseriesRow',
-    'TradeFlow',
-    'TradeFlowDataRequest',
-    'TradeLaneMetric',
+    'TradeFlowServiceAsyncClient',
+'AggregationGroup',
+'AggregationRow',
+'EmptyParams',
+'EmptyResponse',
+'GeoPoint',
+'GetLocationVolumeResponse',
+'GetTradeFlowAggregationResponse',
+'GetTradeFlowHistogramResponse',
+'GetTradeFlowTimeseriesResponse',
+'GetTradeFlowsResponse',
+'GetTradeLaneMetricsResponse',
+'HistogramGroup',
+'LocationVolume',
+'TimeseriesGroup',
+'TimeseriesRow',
+'TradeFlow',
+'TradeFlowDataRequest',
 'TradeFlowServiceClient',
+'TradeLaneMetric',
 )
