@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,26 +13,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions                            # type: ignore
-from google.api_core import gapic_v1                              # type: ignore
-from google.api_core import retry as retries                      # type: ignore
-from google.auth import credentials                               # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials             # type: ignore
 from google.auth.transport import mtls                            # type: ignore
 from google.auth.transport.grpc import SslCredentials             # type: ignore
 from google.auth.exceptions import MutualTLSChannelError          # type: ignore
 from google.oauth2 import service_account                         # type: ignore
 
-from oceanbolt.com.tradeflows_v3.types import service
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from oceanbolt.com.tradeflows_v3.types import service
 from .transports.base import TradeFlowServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import TradeFlowServiceGrpcTransport
 from .transports.grpc_asyncio import TradeFlowServiceGrpcAsyncIOTransport
@@ -47,13 +48,13 @@ class TradeFlowServiceClientMeta(type):
     objects.
     """
     _transport_registry = OrderedDict()  # type: Dict[str, Type[TradeFlowServiceTransport]]
-    _transport_registry['grpc'] = TradeFlowServiceGrpcTransport
-    _transport_registry['grpc_asyncio'] = TradeFlowServiceGrpcAsyncIOTransport
+    _transport_registry["grpc"] = TradeFlowServiceGrpcTransport
+    _transport_registry["grpc_asyncio"] = TradeFlowServiceGrpcAsyncIOTransport
 
     def get_transport_class(cls,
             label: str = None,
         ) -> Type[TradeFlowServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -76,7 +77,8 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -103,14 +105,15 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         return api_endpoint.replace(".googleapis.com", ".mtls.googleapis.com")
 
-    DEFAULT_ENDPOINT = 'api.oceanbolt.com'
+    DEFAULT_ENDPOINT = "api.oceanbolt.com"
     DEFAULT_MTLS_ENDPOINT = _get_default_mtls_endpoint.__func__(  # type: ignore
         DEFAULT_ENDPOINT
     )
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -127,7 +130,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -140,23 +143,24 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         """
         credentials = service_account.Credentials.from_service_account_file(
             filename)
-        kwargs['credentials'] = credentials
+        kwargs["credentials"] = credentials
         return cls(*args, **kwargs)
 
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> TradeFlowServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            TradeFlowServiceTransport: The transport used by the client instance.
+            TradeFlowServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str, ) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(billing_account=billing_account, )
 
     @staticmethod
@@ -167,7 +171,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str, ) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder, )
 
     @staticmethod
@@ -178,7 +182,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str, ) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization, )
 
     @staticmethod
@@ -189,7 +193,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str, ) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project, )
 
     @staticmethod
@@ -200,7 +204,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str, ) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(project=project, location=location, )
 
     @staticmethod
@@ -209,13 +213,72 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(cls, client_options: Optional[client_options_lib.ClientOptions] = None):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError("Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`")
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError("Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`")
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (use_mtls_endpoint == "auto" and client_cert_source):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(self, *,
-            credentials: Optional[credentials.Credentials] = None,
+            credentials: Optional[ga_credentials.Credentials] = None,
             transport: Union[str, TradeFlowServiceTransport, None] = None,
             client_options: Optional[client_options_lib.ClientOptions] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
-        """Instantiate the trade flow service client.
+        """Instantiates the trade flow service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -257,50 +320,32 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(client_options)
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = mtls.default_client_cert_source() if is_mtls else None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError("client_options.api_key and credentials are mutually exclusive")
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, TradeFlowServiceTransport):
             # transport is a TradeFlowServiceTransport instance.
-            if credentials or client_options.credentials_file:
-                raise ValueError('When providing a transport instance, '
-                                 'provide its credentials directly.')
+            if credentials or client_options.credentials_file or api_key_value:
+                raise ValueError("When providing a transport instance, "
+                                 "provide its credentials directly.")
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(google.auth._default, "get_api_key_credentials"):
+                credentials = google.auth._default.get_api_key_credentials(api_key_value)
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -310,12 +355,13 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def get_trade_flows(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowsResponse:
@@ -325,11 +371,29 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         page to return. It is also possible to set the number of
         voyages to return per query.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flows():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flows(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -343,7 +407,6 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.TradeFlowDataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -367,19 +430,36 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         return response
 
     def get_trade_flow_aggregation(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowAggregationResponse:
         r"""Aggregates tradeflow data across multiple dimensions.
 
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_aggregation():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_aggregation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -391,7 +471,6 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.TradeFlowDataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -415,19 +494,36 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         return response
 
     def get_trade_flow_timeseries(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowTimeseriesResponse:
         r"""Gets aggregated trade flow timeseries by period.
 
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_timeseries():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_timeseries(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -441,7 +537,6 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.TradeFlowDataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -465,20 +560,38 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         return response
 
     def get_trade_flow_on_the_water(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowTimeseriesResponse:
         r"""Gets aggregated trade flow timeseries (on the water)
         by period.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_on_the_water():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_on_the_water(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -492,7 +605,6 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.TradeFlowDataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -516,20 +628,38 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         return response
 
     def get_trade_flow_histogram(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowHistogramResponse:
         r"""GetTradeFlowHistogramValues gets trade flow histogram
         values by grouping.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_histogram():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_histogram(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -541,7 +671,6 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.TradeFlowDataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -565,9 +694,9 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         return response
 
     def get_location_volume(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetLocationVolumeResponse:
@@ -575,11 +704,29 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         (port/berth/country/region) flow stats for the given
         filter parameters
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_location_volume():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_location_volume(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -591,7 +738,6 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.TradeFlowDataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -615,20 +761,38 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         return response
 
     def get_trade_lane_metrics(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeLaneMetricsResponse:
         r"""GetTradeflowModelVoyage gets trade flow model voyage
         values by grouping
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_lane_metrics():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_lane_metrics(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -640,7 +804,6 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.TradeFlowDataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -663,16 +826,25 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
 
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
 
-
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
 
 
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            'oceanbolt-com-tradeflows',
+            "oceanbolt-com-tradeflows",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
@@ -680,5 +852,5 @@ except pkg_resources.DistributionNotFound:
 
 
 __all__ = (
-    'TradeFlowServiceClient',
+    "TradeFlowServiceClient",
 )
