@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,8 +14,9 @@
 # limitations under the License.
 #
 
-from oceanbolt.com.vessels_v3.services.vessel_service.async_client import VesselServiceAsyncClient
 from oceanbolt.com.vessels_v3.services.vessel_service.client import VesselServiceClient
+from oceanbolt.com.vessels_v3.services.vessel_service.async_client import VesselServiceAsyncClient
+
 from oceanbolt.com.vessels_v3.types.service import ListStoppageEventsRequest
 from oceanbolt.com.vessels_v3.types.service import ListStoppageEventsResponse
 from oceanbolt.com.vessels_v3.types.service import ListVesselsRequest
@@ -24,13 +24,12 @@ from oceanbolt.com.vessels_v3.types.service import ListVesselsResponse
 from oceanbolt.com.vessels_v3.types.service import StoppageEvent
 from oceanbolt.com.vessels_v3.types.service import Vessel
 
-__all__ = (
+__all__ = ('VesselServiceClient',
+    'VesselServiceAsyncClient',
     'ListStoppageEventsRequest',
     'ListStoppageEventsResponse',
     'ListVesselsRequest',
     'ListVesselsResponse',
     'StoppageEvent',
     'Vessel',
-    'VesselServiceAsyncClient',
-    'VesselServiceClient',
 )
