@@ -6,6 +6,10 @@ from oceanbolt.sdk.data import TonnageZoneTimeseries, FleetSpeedTimeseries, Chin
 from oceanbolt.sdk.data import CongestionVessels, CongestionTimeseries
 from oceanbolt.sdk.data import DryDockTimeseries, DryDockCurrentVessels, DryDockHistoricalStays
 from oceanbolt.sdk.data import Vessels
+from oceanbolt.sdk.data import VesselStates, VesselStatesForDate
+
+from oceanbolt.sdk.data import CustomPolygonTimeseries
+
 
 __client__ = APIClient()
 
@@ -53,6 +57,16 @@ def test_search_vessels():
 
 
 # Data endpoints
+def test_vessel_states():
+    df = VesselStates(__client__).get(imo=[9583706, 9659828], start_date="2020-01-01", end_date="2021-01-01")
+    assert len(df) > 0
+
+
+def test_vessel_states_for_date():
+    df = VesselStatesForDate(__client__).get(date="2020-01-01")
+    assert len(df) > 0
+
+
 def test_congestion_vessels():
     df = CongestionVessels(__client__).get(country_code=["cn"], start_date="2021-01-01")
     assert len(df) > 0
@@ -131,7 +145,7 @@ def test_chinese_waters():
 # def test_custom_polygon():
 #     df = CustomPolygonTimeseries(__client__).get(
 #         geojson="{\"type\":\"Polygon\",\"coordinates\":[[[45.50537109374999,31.93351676190369],[50.4931640625,16.846605106396304],[61.083984375,20.138470312451155],[66.9287109375,27.819644755099446],[61.94091796875,31.89621446335144],[45.50537109374999,31.93351676190369]]]}",
-#         start_date="2015-01-01",
+#         start_date="2021-01-01",
 #         end_date="2021-03-01",
 #         sub_segment=["ultramax"]
 #
